@@ -50,7 +50,7 @@ $YAHOO_CURRENCY_URL = "http://uk.finance.yahoo.com/currency/convert?amt=1&submit
 @EXPORT_OK = qw/yahoo yahoo_europe fidelity troweprice asx tiaacref/;
 @EXPORT_TAGS = ( all => [@EXPORT_OK]);
 
-$VERSION = '1.14';
+$VERSION = '1.15';
 
 $USE_EXPERIMENTAL_UA = 0;
 
@@ -670,11 +670,10 @@ sub isoTime {
   $timeString = uc $timeString ;
   my $retTime = "00:00"; # return zero time if unparsable input
   if ($timeString=~m/^(\d+)[\.:UH](\d+)(AM|PM)?/) {
-    my ($hours,$mins)= ($1,$2) ;
+    my ($hours,$mins)= ($1-0,$2-0) ;
     $hours+=12 if ($3 && ($3 eq "PM")) ;
     if ($hours>=0 && $hours<=23 && $mins>=0 && $mins<=59 ) {
-      $retTime = $hours>=10 ? "$hours:" : "0$hours:" ;
-      $retTime.= $mins>=10 ? "$mins" :"0$mins" ;
+      $retTime = sprintf ("%02d:%02d", $hours, $mins) ;
     }
   }
   return $retTime;
